<?php namespace EwTools\Handler;

use EwTools\Support\Str;
use EwTools\Twig\View;

/**
 * JsonImporter
 *
 * @link    http://infomaker.se
 * @package EwTools\Handler
 * @since   EwTools\Handler\JsonImporter 0.1
 */
class JsonImporter {
    
    /**
     *
     *
     * @var string
     */
    protected $submit_name = 'imported-data';
    
    /**
     * JsonImporter constructor.
     *
     * @since 0.1
     *
     * @param string $submit_name
     */
    public function __construct( $submit_name='' ) {
        if ( Str::notEmpty($submit_name) ) {
            $this->submit_name = Str::slug($submit_name);
        }
    }
    
    /**
     * Determine if data has been imported
     *
     * @since 0.1
     * @return bool
     */
    public function isImported() {
        return isset( $_POST[ $this->submit_name ] );
    }
    
    /**
     * Function for adding imported sections to the existing list
     *
     * @since 0.1
     * @return array
     */
    public function getJson() {
        if ( $this->isImported() ) {
            $json = array_get( $_POST, $this->submit_name, '' );
            $data = json_decode( stripslashes( $json ), true );
            
            return $data !== null ? array_filter( $data ) : [];
        }
        return [];
    }
    
    /**
     * Generate an Import export module
     *
     * @param string $import
     * @param string $export
     * @param string $template
     *
     * @return string
     * @since 0.1
     */
    public function generate($import='', $export='', $template = null) {
        
        return View::generate($template !== null ? $template : '@tools/utilities/import-export', [
            'field_name' => $this->submit_name,
            'import' => $import,
            'export' => $export
        ]);
    }
}