<?php
/**
 * Page Subhead metabox.
 *
 * Metabox Name: Page Subhead
 * Description: Add and manage a page-specific subheader
 * Version: 0.1
 * Author: Infomaker Scandinavia AB
 * Author URI: http://infomaker.se
 */
namespace EwTools\Metaboxes;

use EwTools\Admin\Metabox;
use EwTools\Handler\Menus;
use EwTools\Models\Section;

/**
 * PageSubHead
 *
 * @link    http://infomaker.se
 * @package EwTools\Metaboxes
 * @since   EwTools\Metaboxes\PageSubHead 0.1
 */
class PageSubHead extends Metabox {
    
    /**
     * postmeta id
     *
     * @see Metabox::$postmeta_id
     * @var string
     */
    public static $postmeta_id = 'ew_page_subhead_box';
    
    /**
     * metabox id
     *
     * @see Metabox::$meta_box_id
     * @var string
     */
    protected $meta_box_id = 'ew-page-subhead-box';
    
    /**
     * Twig-template to use
     *
     * @var string
     */
    protected $template_path = '@tools/metaboxes/page-subhead';
    
    /**
     * Metabox fields:
     * Contains fields to add and manage a page-specific subheader
     *
     * @var array
     */
    protected $fields = [
        'title'   => '',
        'menu'    => '',
        'section' => '',
        'logo'    => '',
        'use_parent'  => false,
        'use_submenu' => false
    ];
    
    /**
     * PageSubHead constructor.
     *
     * @param string $title
     *
     * @since 0.1
     */
    public function __construct( $title = 'Page Subhead' ) {
        $this->setMetaboxData(__FILE__);
        parent::__construct( $title );
    }
    
    /**
     * Render the metabox form
     *
     * @param string $view_data
     *
     * @since 0.1
     * @return void
     */
    protected function edit( $view_data ) {
        $this->view('form', array_replace_recursive([
            'menus' => Menus::toSelect($view_data['menu']['value']),
            'sections' => Section::toSelect($view_data['section']['value']),
        ], $view_data));
    }
}