<?php namespace EwTools\Models;

use EwTools\Interfaces\Support\Selectable;
use EwTools\Support\Str;

/**
 * Everyboard
 *
 * @property mixed id
 *
 * @link    http://infomaker.se
 * @package EwTools\Models
 * @since   EwTools\Models\Everyboard 0.1
 */
class Everyboard extends Post implements Selectable {
    
    protected static $type = 'everyboard';
    
    /**
     * Retrieve the content of the board in the form of an array or json string if specified
     *
     * @param bool $to_array
     *
     * @since 0.1
     * @return array|string
     */
    public function boardContent( $to_array = false ) {
        $content = $this->getMeta( 'everyboard_json', '' );
        if( $to_array ) {
            return Str::notEmpty( $content ) ? json_decode( $content, true ) : [];
        }
        
        return $content;
    }
    
    /**
     * Return data in the form of an array fit for a select-box
     * A preselected value may be sent in.
     *
     * @param mixed $selected
     *
     * @since 0.1
     * @return array
     */
    public static function toSelect( $selected = null ) {
        return static::all()->map( function ( self $board ) use ( $selected ) {
            return [
                'value'    => $board->id,
                'text'     => $board->title(),
                'selected' => $board->id === $selected
            ];
        } )->toArray();
    }
}